InMemoryLoggerSink class final

An in-memory LoggerSink with FIFO fault injection.

Implemented types

Constructors

InMemoryLoggerSink()

Properties

flushCount int
How many times flush was called.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
records List<LogRecord>
Every record accepted by emit, in call order.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

emit(LogRecord record) → Result<void>
Emits one record.
override
enqueue(Result<void> result) → void
Scripts the next emit answer.
enqueueFlushResult(Result<void> result) → void
Scripts the next flush answer.
flush() Future<Result<void>>
Flushes any buffered records.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited